==> haskell-th-utilities-0.2.0.1-27-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-th-utilities.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-utilities
version: 0.2.0.1
id: th-utilities-0.2.0.1-EmlHlxT23fg3TvsuWVoEuJ
key: th-utilities-0.2.0.1-EmlHlxT23fg3TvsuWVoEuJ
license: MIT
copyright: 2016 FP Complete
maintainer: Michael Sloan <sloan@fpcomplete.com>
homepage: https://github.com/fpco/th-utilities#readme
synopsis: Collection of useful functions for use with Template Haskell
category: Template Haskell
exposed: True
indefinite: False
exposed-modules:
    TH.Derive TH.Derive.Storable TH.ReifySimple TH.RelativePaths
    TH.Utilities
hidden-modules: TH.Derive.Internal
abi: 115fbec7fc3df71eeb1106b749f56eb5
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/th-utilities-0.2.0.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/th-utilities-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/th-utilities-0.2.0.1
hs-libraries: HSth-utilities-0.2.0.1-EmlHlxT23fg3TvsuWVoEuJ
depends:
    base-4.10.1.0 bytestring-0.10.8.2 containers-0.5.10.2
    directory-1.3.0.2 filepath-1.4.1.2
    primitive-0.6.3.0-CXy1O9sQYlI58rn9KQkFyo
    syb-0.7-3Lq8MQxmYP07qktjI1jxu0 template-haskell-2.12.0.0
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    th-orphans-0.13.5-t0CEVQdE9c8I5D2IHhxnS
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             primitive-0.6.3.0-CXy1O9sQYlI58rn9KQkFyo=b4457a9f891c4eea587ee58a79b7f0fc
             syb-0.7-3Lq8MQxmYP07qktjI1jxu0=f985ea42a9fa578e0f67572a93e19b5d
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             th-orphans-0.13.5-t0CEVQdE9c8I5D2IHhxnS=6ddf5551164c40b78e5ec80cc258bdd5
haddock-interfaces: /usr/share/doc/haskell-th-utilities/html/th-utilities.haddock
haddock-html: /usr/share/doc/haskell-th-utilities/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-utilities-0.2.0.1-29-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-th-utilities.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-utilities
version: 0.2.0.1
id: th-utilities-0.2.0.1-GJcNRcXFM46LeSYO0eA9Pp
key: th-utilities-0.2.0.1-GJcNRcXFM46LeSYO0eA9Pp
license: MIT
copyright: 2016 FP Complete
maintainer: Michael Sloan <sloan@fpcomplete.com>
homepage: https://github.com/fpco/th-utilities#readme
synopsis: Collection of useful functions for use with Template Haskell
category: Template Haskell
exposed: True
indefinite: False
exposed-modules:
    TH.Derive TH.Derive.Storable TH.ReifySimple TH.RelativePaths
    TH.Utilities
hidden-modules: TH.Derive.Internal
abi: 567c982bbe3574e17d93e0144adcd10b
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/th-utilities-0.2.0.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/th-utilities-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/th-utilities-0.2.0.1
hs-libraries: HSth-utilities-0.2.0.1-GJcNRcXFM46LeSYO0eA9Pp
depends:
    base-4.10.1.0 bytestring-0.10.8.2 containers-0.5.10.2
    directory-1.3.0.2 filepath-1.4.1.2
    primitive-0.6.3.0-CXy1O9sQYlI58rn9KQkFyo
    syb-0.7-3Lq8MQxmYP07qktjI1jxu0 template-haskell-2.12.0.0
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
    th-orphans-0.13.5-HSlHCLPBuTv8SS04QFxpWE
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             primitive-0.6.3.0-CXy1O9sQYlI58rn9KQkFyo=b4457a9f891c4eea587ee58a79b7f0fc
             syb-0.7-3Lq8MQxmYP07qktjI1jxu0=f985ea42a9fa578e0f67572a93e19b5d
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             th-orphans-0.13.5-HSlHCLPBuTv8SS04QFxpWE=e423584e44e2533ee94520d813bdf522
haddock-interfaces: /usr/share/doc/haskell-th-utilities/html/th-utilities.haddock
haddock-html: /usr/share/doc/haskell-th-utilities/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
